# textual-enhanced ChangeLog

## v0.8.0

**Released: 2025-03-15***

- Added the idea of a `HelpfulBinding`.
  ([#27](https://github.com/davep/textual-enhanced/pull/27))

## v0.7.1

**Released: 2025-03-07***

- Added a temporary workaround for Textual 2.0.x's kinda-unannounced
  breaking change to how the command palette works.
  (#23[](https://github.com/davep/textual-enhanced/pull/23))

## v0.7.0

**Released: 2025-03-02***

- Added `maybe` to `CommandsProvider`.

## v0.6.0

**Released: 2025-02-12**

- Added `initial` to `ModalInput`.
  ([#17](https://github.com/davep/textual-enhanced/pull/17))

## v0.5.0

**Released: 2025-02-08**

- Tweaked the styling of the command palette's scrollbar so it's less
  intrusive. ([#14](https://github.com/davep/textual-enhanced/pull/14))
- Added `ChangeTheme` as a common command.
  ([#15](https://github.com/davep/textual-enhanced/pull/15))
- Added handling code for the common commands to `EnhancedScreen`.
  ([#15](https://github.com/davep/textual-enhanced/pull/15))

## v0.4.0

**Released: 2025-02-03**

- Allow forcing `dim` when adding a key with `add_key`.
  ([#11](https://github.com/davep/textual-enhanced/pull/11))
- Added `EnhancedScreen`.
  ([#12](https://github.com/davep/textual-enhanced/pull/12))

## v0.3.0

**Released: 2025-02-03**

- Added `Confirm`. ([#8](https://github.com/davep/textual-enhanced/pull/8))
- Added `add_key`. ([#9](https://github.com/davep/textual-enhanced/pull/9))

## v0.2.0

**Released: 2025-02-02**

- Added `ModalInput`.
  ([#3](https://github.com/davep/textual-enhanced/pull/3))
- Added `HelpScreen`.
  ([#5](https://github.com/davep/textual-enhanced/pull/5))
- Added common command messages and a common command provider.
  ([#5](https://github.com/davep/textual-enhanced/pull/5))

## v0.1.0

**Released: 2025-02-01**

- Initial release.

[//]: # (ChangeLog.md ends here)
